camelot.camelot.view.controls.animation.MovieWidget

Package camelot :: Package camelot :: Package view :: Package controls :: Module animation :: Class MovieWidget |
[hide private]
[frames] | no frames]

# Class MovieWidget

source code

Simulates a QMovie using a QLabel

Instance Methods | [hide private]
__init__(self, icons, parent=None) | source code
_create_pixmaps(self, icons) | source code
startMovie(self) | source code
stopMovie(self) | source code
timerEvent(self, event) | source code